@@ -10,7 +10,6 @@
 #include <config-platformtheme.h>
 
 #include "kdeplatformfiledialoghelper.h"
-#include "kdeplatformfontdialoghelper.h"
 #include "kdeplatformsystemtrayicon.h"
 #include "kdeplatformtheme.h"
 #include "kfontsettingsdata.h"
@@ -192,6 +191,12 @@ KdePlatformTheme::KdePlatformTheme()
     QCoreApplication::setAttribute(Qt::AA_DontUseNativeMenuBar, false);
     setQtQuickControlsTheme();
 
+    static KIOUiFactory factory;
+    KIO::setDefaultJobUiDelegateFactory(&factory);
+
+    static KIOUiDelegate delegateExtension;
+    KIO::setDefaultJobUiDelegateExtension(&delegateExtension);
+
     KCountryFlagEmojiIconEngine::setGlobalDefaultFont(QFont(u"Noto Color Emoji, emoji"_qs));
 }
 
@@ -379,7 +384,7 @@ QList<QKeySequence> KdePlatformTheme::keyBindings(QKeySequence::StandardKey key)
 
 bool KdePlatformTheme::usePlatformNativeDialog(QPlatformTheme::DialogType type) const
 {
-    return (type == QPlatformTheme::FileDialog || type == QPlatformTheme::FontDialog) && qobject_cast<QApplication *>(QCoreApplication::instance());
+    return type == QPlatformTheme::FileDialog && qobject_cast<QApplication *>(QCoreApplication::instance());
 }
 
 QString KdePlatformTheme::standardButtonText(int button) const
@@ -439,7 +444,6 @@ QPlatformDialogHelper *KdePlatformTheme::createPlatformDialogHelper(QPlatformThe
         }
         return new KDEPlatformFileDialogHelper;
     case QPlatformTheme::FontDialog:
-        return new KDEPlatformFontDialogHelper;
     case QPlatformTheme::ColorDialog:
     case QPlatformTheme::MessageDialog:
     default:
